@@ -40,26 +40,26 @@ class Measurement:
                 False: self.std_dev,
             }
 
-        try:
-            self.direction = "Z"
-            pdd.calculate_parameters(
-                np.array(self.axis[False]),
-                self.dose[False] / max(self.dose[False]),
-                [],
-            )
-        except Exception:
-            try:
-                self.direction = "X"
-                dp.calculate_parameters(
-                    np.array(self.axis[False]),
-                    self.dose[False] / max(self.dose[False]),
-                    [],
-                )
-                dialog = GetType(self, self.parent, "NoPDD")
-                self.parent.parent.wait_window(dialog.top)
-            except Exception:
-                dialog = GetType(self, self.parent, "")
-                self.parent.parent.wait_window(dialog.top)
+        # try:
+        #    self.direction = "Z"
+        #    pdd.calculate_parameters(
+        #        np.array(self.axis[False]),
+        #        self.dose[False] / max(self.dose[False]),
+        #        [],
+        #    )
+        # except Exception:
+        #    try:
+        #        self.direction = "X"
+        #        dp.calculate_parameters(
+        #            np.array(self.axis[False]),
+        #            self.dose[False] / max(self.dose[False]),
+        #            [],
+        #        )
+        #        dialog = GetType(self, self.parent, "NoPDD")
+        #        self.parent.parent.wait_window(dialog.top)
+        #    except Exception:
+        dialog = GetType(self, self.parent, "")
+        self.parent.parent.wait_window(dialog.top)
 
     def params(self):
         if self.direction == "Z":
